---
hide:
  - navigation
  - toc
---

# benchmark-tool

A tool to simplify the generation, execution, and evaluation of benchmarks.

This documentation covers:

- **Getting Started:** An introduction to the tool and instructions for use.
- **Examples:** Demonstrations of all tool components.
- **References:** Detailed documentation and technical information.
- **Community:** Contact details and ways to contribute to the project.

!!! info
    The _benchmark-tool_ is part of the [Potassco](https://potassco.org) suite.

    This project is currently under active development.

    Functionality is verified only on Linux. Issues may occur on other platforms.
